@@ -34,11 +34,7 @@ pgf_with_latex = {                      # setup matplotlib to use latex for outp
     "xtick.major.size": 6,
     "xtick.major.width": 2,
     "xtick.direction": "in",            
-    "figure.figsize": figsize(1.4),       # default fig size of 0.9 textwidth
-    "pgf.preamble": [
-        r"\usepackage[utf8x]{inputenc}",    # use utf8 fonts becasue your computer can handle it :)
-        r"\usepackage[T1]{fontenc}",        # plots will be generated using this preamble
-        ]
+    "figure.figsize": figsize(1.4)       # default fig size of 0.9 textwidth
     }
 
 
@@ -101,7 +97,7 @@ def save_proj(x,y,ytot,convolution, k,freq,n,namedir, params, max_Z):
     ax1.tick_params(axis='x', labelsize=16, width=2 , length=6, direction='in')
     
     
-    plt.tight_layout()
+    # plt.tight_layout()
     fig0.savefig(name_current_dir+'/proj_'+str(k)+'mode'+str(n)+'_spectrum.pdf')
 # =============================================================================
 
@@ -132,7 +128,7 @@ def save_proj(x,y,ytot,convolution, k,freq,n,namedir, params, max_Z):
     ax1.set_xlim(-1*33.35641,25*33.35641)
     ax1.tick_params(axis='x', labelsize=16, width=2 , length=6, direction='in')
     
-    plt.tight_layout()
+    # plt.tight_layout()
     fig.savefig(name_current_dir+'/proj_'+str(k)+'mode'+str(n)+'.pdf')
 # =============================================================================
    
@@ -173,7 +169,7 @@ def save_proj(x,y,ytot,convolution, k,freq,n,namedir, params, max_Z):
     ax1.tick_params(axis='x', labelsize=16, width=2 , length=6, direction='in')
     
     
-    plt.tight_layout()
+    # plt.tight_layout()
     fig1.savefig(name_current_dir+'/proj_'+str(k)+'mode'+str(n)+'_lorentzian.pdf')
 # =============================================================================
 
@@ -231,7 +227,7 @@ def plot_k2(kk, kk_many, frequencies_disp, frequencies_ft, f, data, data_project
 
     plt.show()
     plt.title('Spectrum branches '+str(branches))
-    plt.tight_layout()
+    # plt.tight_layout()
     fig.savefig('plot5_'+str(branches)+'.pdf', backend='pgf')
     return 
 
@@ -255,7 +251,7 @@ def plot1(freq,ZQS, labels, max_Z):
         axs[i].set_yticks([])
 #    plt.ylabel('K-point DOS [kB T * ps]')
     plt.xlabel('Frequency [Thz]')
-    plt.tight_layout()
+    # plt.tight_layout()
     plt.show() 
     fig.savefig('plot1.pdf')
     return
@@ -287,7 +283,7 @@ def plot2(freq,ZQS,modes, labels, freqs_from_disp, max_Z):
         
 #        plt.ylabel('K-point DOS [kB T * ps]')
         plt.xlabel('Frequency [Thz]')
-        plt.tight_layout()
+        # plt.tight_layout()
         plt.show() 
         fig.savefig('plot2_'+str(n)+'.pdf')
     return
@@ -464,7 +460,7 @@ def plot_eigvec_noani(Ruc, n_uc, k,eigvec,freq, ax,fig, masses):
     ax.legend(fontsize='x-small')
 #    ax.set_xticks(np.arange(Ruc[0::3].max())), ax.set_yticks(np.arange(Ruc[1::3].max())), ax.set_zticks(np.arange(Ruc[2::3].max()))
 #    ax.set_xticks([]), ax.set_yticks([]), ax.set_zticks([])
-    plt.tight_layout()
+    # plt.tight_layout()
     return 
 
 def plot6(x,y,ytot, k,eigvec,freq,n,Ruc,masses, max_Z, title=''):
@@ -508,7 +504,7 @@ def plot6(x,y,ytot, k,eigvec,freq,n,Ruc,masses, max_Z, title=''):
         ax.set_ylim(bottom=-max_Z/10,top=max_Z)
         
     plt.show()
-    plt.tight_layout()
+    # plt.tight_layout()
     fig.savefig('plot6_'+str(np.round(k))+'_mode_'+str(n)+'.pdf')
     return ani
 
