@@ -147,8 +147,24 @@ def get_commensurate_kpath(file, N1,N2,N3, N1_FC,N2_FC,N3_FC, kinput_scaled, lab
 
     # =============================================================================
     
+    #  check that input k's are not inside kdef
+    y1 = np.linspace(0,1,N1_FC+1)
+    y2 = np.linspace(0,1,N2_FC+1)
+    y3 = np.linspace(0,1,N3_FC+1)
+    comb2 = np.array(np.meshgrid(y1,y2,y3)).T.reshape(-1,3)
+
     kdef_scaled = np.array(kdef_scaled)
-    kdef = np.dot(Hk,kdef_scaled.T).T
+    indexes_to_delete = []
+    #  check that input k's are not inside kdef
+    for j in range(len(kdef_scaled)):
+        this_k = kdef_scaled[j]
+        if not ( np.any(np.all(np.isclose(this_k , comb2), axis=1)) ):
+            indexes_to_delete.append(j)
+    kdef_scaled_checked = np.delete(kdef_scaled, indexes_to_delete, axis=0)
+
+
+    kdef_scaled = kdef_scaled_checked
+    kdef = np.dot(Hk,kdef_scaled_checked.T).T
     Nqpoints = len(kdef)
     
     # =============================================================================
